@@ -9,17 +9,17 @@
 #' area <- Intergration(data)
 #' }
 #' @export
-Integration <- function(data, rt = c(8.3, 9), brt = c(8.3,
+Integration <- function(data, rt = c(8.3, 9), brt = c(8.3, 
     8.4), smoothit = T) {
     # subset the data
-    subdata <- data[data[, 1] > rt[2] & data[, 1] <
-        rt[1], ]
+    subdata <- data[data[, 1] > rt[2] & data[, 1] < rt[1], 
+        ]
     # get the signal and the RT
     RTrange <- subdata[, 1]
     signal <- subdata[, 2]
     # subset the noise
-    subnoise <- data[data[, 1] > brt[2] & data[, 1] <
-        brt[1], ]
+    subnoise <- data[data[, 1] > brt[2] & data[, 1] < brt[1], 
+        ]
     # get the noise and the RT
     RTrange2 <- subnoise[, 1]
     noise <- subnoise[, 2]
@@ -31,11 +31,11 @@ Integration <- function(data, rt = c(8.3, 9), brt = c(8.3,
     baseline <- mean(noise)
     signaln <- signal - baseline
     area <- 0
-    # calculate area; using a Riemann integral
-    # (dimension: intensity x delta time)
+    # calculate area; using a Riemann integral (dimension:
+    # intensity x delta time)
     for (i in 1:(length(RTrange) - 1)) {
-        area <- area + signaln[i] * (RTrange[i + 1] -
-            RTrange[i]) * 60
+        area <- area + signaln[i] * (RTrange[i + 1] - RTrange[i]) * 
+            60
     }
     return(area)
 }
@@ -56,12 +56,12 @@ Integration <- function(data, rt = c(8.3, 9), brt = c(8.3,
 #' list <- GetIntergration(data)
 #' }
 #' @export
-GetIntegration <- function(data, rt = c(8.3, 9), n = 5,
-    m = 5, slope = c(2, 2), baseline = 10, noslope = T,
+GetIntegration <- function(data, rt = c(8.3, 9), n = 5, 
+    m = 5, slope = c(2, 2), baseline = 10, noslope = T, 
     smoothit = T, half = F) {
     # subset the data
-    subdata <- data[data[, 1] > rt[1] & data[, 1] <
-        rt[2], ]
+    subdata <- data[data[, 1] > rt[1] & data[, 1] < rt[2], 
+        ]
     # get the signal and the RT
     RTrange <- subdata[, 1]
     signal <- subdata[, 2]
@@ -76,93 +76,91 @@ GetIntegration <- function(data, rt = c(8.3, 9), n = 5,
     forth <- m - back
     if (m > 2) {
         for (i in (back + 1):(length(signal) - forth)) {
-            slopedata[i] <- stats::coef(stats::lm(signal[(i -
-                back + 1):(i + forth)] ~ RTrangemsec[(i -
+            slopedata[i] <- stats::coef(stats::lm(signal[(i - 
+                back + 1):(i + forth)] ~ RTrangemsec[(i - 
                 back + 1):(i + forth)]))[2]
         }
         slopedata[1:back] <- slopedata[back + 1]  # first few points
-        slopedata[(length(signal) - forth - 1):length(signal)] <- slopedata[(length(signal) -
+        slopedata[(length(signal) - forth - 1):length(signal)] <- slopedata[(length(signal) - 
             forth)]  # last few points
     } else {
         # for n = 2 points; without linear regression (much
         # faster) time per scan in millisec
-        delta_t <- (t[length(RTrangemsec)] - RTrangemsec[1]/(length(RTrangemsec) -
+        delta_t <- (t[length(RTrangemsec)] - RTrangemsec[1]/(length(RTrangemsec) - 
             1))
         for (i in 2:length(signal)) {
-            slopedata[i] <- (signal[i] - signal[i -
-                1])/delta_t
+            slopedata[i] <- (signal[i] - signal[i - 1])/delta_t
         }
         slopedata[1] <- 0
     }
     # search for peak start
     i <- baseline
-    while ((slopedata[i] <= (slope[1]/100 * max(slopedata))) &
+    while ((slopedata[i] <= (slope[1]/100 * max(slopedata))) & 
         (i < length(signal))) i <- i + 1
     rtstart <- RTrange[i]  # peak start found
     scanstart <- i  # (slope > threshold)
     sigstart <- mean(signal[(i - baseline + 1):i])  # baseline intensity found
     # search for peak top
     i <- which.max(slopedata)  # jump to slope max.
-    while ((slopedata[i] >= 0) & (i < (length(signal) -
+    while ((slopedata[i] >= 0) & (i < (length(signal) - 
         baseline))) i <- i + 1
     rtpeak <- RTrange[i]  # peak top found
     scanpeak <- i  # (slope = 0)
     sigpeak <- signal[i]
     # search for peak end
     i <- which.min(slopedata)  # jump to slope min.
-    while ((slopedata[i] <= -(slope[2]/100 * max(slopedata))) &
-        (i < (length(signal) - baseline))) i <- i +
-        1
+    while ((slopedata[i] <= -(slope[2]/100 * max(slopedata))) & 
+        (i < (length(signal) - baseline))) i <- i + 1
     rtend <- RTrange[i]  # peak end found
     scanend <- i  # (-slope < threshold)
     sigend <- mean(signal[i:(i + baseline - 1)])
     # if background without slope
-    if (!noslope)
+    if (!noslope) 
         sigend <- sigstart
     # subtract background from signal
     background <- signal
     for (i in scanstart:scanend) {
         # get background
-        background[i] <- sigstart + (sigend - sigstart)/(scanend -
+        background[i] <- sigstart + (sigend - sigstart)/(scanend - 
             scanstart) * (i - scanstart)
     }
     subsignal <- signal - background
     # get the length of the signal
     lengthsig <- length(scanstart:scanend)
-    # calculate area; using a Riemann integral
-    # (dimension: intensity x min)
+    # calculate area; using a Riemann integral (dimension:
+    # intensity x min)
     area <- 0
-    scantime <- (RTrange[scanend] - RTrange[scanstart])/(scanend -
+    scantime <- (RTrange[scanend] - RTrange[scanstart])/(scanend - 
         scanstart) * 60  # time per scan in second
     # when half peak
     if (half == T) {
-        for (i in scanstart:scanpeak) area <- area +
-            subsignal[i] * scantime
+        for (i in scanstart:scanpeak) area <- area + subsignal[i] * 
+            scantime
     } else {
-        for (i in scanstart:scanend) area <- area +
-            subsignal[i] * scantime
+        for (i in scanstart:scanend) area <- area + subsignal[i] * 
+            scantime
     }
     bgstart <- RTrange[scanstart - baseline + 1]
     bgend <- RTrange[scanend + baseline - 1]
     # calculate height
-    sigpeakbase <- sigstart + (sigend - sigstart)/(scanend -
+    sigpeakbase <- sigstart + (sigend - sigstart)/(scanend - 
         scanstart) * (scanpeak - scanstart)
     height <- sigpeak - sigpeakbase
     # SNR
-    snrnoise <- abs(diff(range(signal[(scanstart -
-        baseline + 1):scanstart])))
+    snrnoise <- abs(diff(range(signal[(scanstart - baseline + 
+        1):scanstart])))
     SNR <- height/snrnoise
     # collect the data for plot peak and slope
-    peakdata <- c(baseline, rtstart, rtend, rtpeak,
-        scanstart, scanend, scanpeak, sigstart, sigend,
-        sigpeak, sigpeakbase, lengthsig, SNR)
-    names(peakdata) <- c("baseline", "peak start RT",
-        "peak end RT", "peak RT", "baseline start RT ID",
-        "baseline end RT ID", "baseline peak RT ID",
-        "start RT intensity", "end RT intensity", "peak RT intensity",
-        "peak baseline", "points", "SNR")
+    peakdata <- c(baseline, rtstart, rtend, rtpeak, scanstart, 
+        scanend, scanpeak, sigstart, sigend, sigpeak, sigpeakbase, 
+        lengthsig, SNR)
+    names(peakdata) <- c("baseline", "peak start RT", "peak end RT", 
+        "peak RT", "baseline start RT ID", "baseline end RT ID", 
+        "baseline peak RT ID", "start RT intensity", "end RT intensity", 
+        "peak RT intensity", "peak baseline", "points", 
+        "SNR")
     # return the result as a list
-    list <- list(area = area, height = height, peakdata = peakdata,
+    list <- list(area = area, height = height, peakdata = peakdata, 
         RTrange = RTrange, signal = signal, slopedata = slopedata)
     return(list)
 }
@@ -190,8 +188,8 @@ batch <- function(file, mz1, mz2) {
     name2 <- paste("m/z:", mz2)
     xl <- GetIntegration(xa, name1)
     xh <- GetIntegration(xb, name2)
-    graphics::par(mfrow = c(2, 2), mar = c(2, 2, 2,
-        2), oma = c(0, 0, 0, 0))
+    graphics::par(mfrow = c(2, 2), mar = c(2, 2, 2, 2), 
+        oma = c(0, 0, 0, 0))
     plotint(xl, name1)
     plotintslope(xl, name1)
     plotint(xh, name2)
@@ -203,8 +201,7 @@ batch <- function(file, mz1, mz2) {
     heightratio <- height[1]/height[2]
     points <- round(mean(sapply(list, function(x) x$peakdata[12])))
     ratio <- c(arearatio, heightratio, points)
-    names(ratio) <- c("area ratio", "height ratio",
-        "points")
+    names(ratio) <- c("area ratio", "height ratio", "points")
     return(ratio)
 }
 
@@ -220,7 +217,7 @@ batch <- function(file, mz1, mz2) {
 #' arearatio <- qbatch(datafile)
 #' }
 #' @export
-qbatch <- function(file, mz1, mz2, rt = c(8.65, 8.74),
+qbatch <- function(file, mz1, mz2, rt = c(8.65, 8.74), 
     brt = c(8.74, 8.85)) {
     data1 <- xcms::xcmsRaw(file)
     df <- data1@env$profile
@@ -243,21 +240,21 @@ qbatch <- function(file, mz1, mz2, rt = c(8.65, 8.74),
 #' @examples
 #' \dontrun{
 #' # show isotopologues for BDE-47
-#' ir <- Getisotopologues(formula = "C12OH6Br4")
+#' ir <- Getisotopologues(formula = 'C12OH6Br4')
 #' }
 #' @export
-Getisotopologues <- function(formula = "C12OH6Br4",
-    charge = "1", width = 0.3) {
+Getisotopologues <- function(formula = "C12OH6Br4", charge = "1", 
+    width = 0.3) {
     # input the forlmula and charge for your molecular,
     # this demo was for BDE-47
     formula <- rcdk::get.formula(formula, charge)
-    # get the isotopes pattern of your molecular with
-    # high abandances. Here we suggest more than 10%
-    # abundance of your base peak would meet the SNR
-    isotopes <- data.frame(rcdk::get.isotopes.pattern(formula,
+    # get the isotopes pattern of your molecular with high
+    # abandances. Here we suggest more than 10% abundance
+    # of your base peak would meet the SNR
+    isotopes <- data.frame(rcdk::get.isotopes.pattern(formula, 
         minAbund = 0.1))
     # order the intensity by the abandance
-    findpairs <- isotopes[order(isotopes[, 2], decreasing = T),
+    findpairs <- isotopes[order(isotopes[, 2], decreasing = T), 
         ]
     # find the most similar pairs with high abandance
     df <- outer(findpairs[, 2], findpairs[, 2], "/")
@@ -269,56 +266,17 @@ Getisotopologues <- function(formula = "C12OH6Br4",
     isotopologuesL <- min(isotopologues1, isotopologues2)
     isotopologuesH <- max(isotopologues1, isotopologues2)
     # get the caculated ratio at certain resolution
-    isotopes2 <- rcdk::get.isotopes.pattern(formula,
-        minAbund = 1e-08)
-    ratio <- sum(isotopes2[isotopes2[, 1] > isotopologuesL -
-        width & isotopes2[, 1] < isotopologuesL + width,
-        2])/sum(isotopes2[isotopes2[, 1] > isotopologuesH -
-        width & isotopes2[, 1] < isotopologuesH + width,
+    isotopes2 <- rcdk::get.isotopes.pattern(formula, minAbund = 1e-08)
+    ratio <- sum(isotopes2[isotopes2[, 1] > isotopologuesL - 
+        width & isotopes2[, 1] < isotopologuesL + width, 
+        2])/sum(isotopes2[isotopes2[, 1] > isotopologuesH - 
+        width & isotopes2[, 1] < isotopologuesH + width, 
         2])
-    peak <- c(round(isotopologuesL, digits = 1), round(isotopologuesH,
+    peak <- c(round(isotopologuesL, digits = 1), round(isotopologuesH, 
         digits = 1), round(ratio, digits = 5))
     # peak <- as.character(peak)
-    names(peak) <- c("light isotopologue", "high isotopologue",
+    names(peak) <- c("light isotopologue", "high isotopologue", 
         "caculated ratio")
     return(data.frame(peak))
 }
 
-#' Get mass defect with certain scaled factor
-#' @param mass vector of mass
-#' @param sf scaled factors
-#' @return dataframe with mass, scaled mass and scaled mass defect
-#' @examples
-#' mass <- c(100.1022,245.2122,267.3144,400.1222,707.2294)
-#' sf <- 0.9988
-#' mf <- getmassdefect(mass,sf)
-#' @export
-getmassdefect <- function(mass, sf) {
-        sm <- mass * sf
-        sd <- ceiling(sm) - sm
-        df <- as.data.frame(cbind(mass, sm, sd))
-        graphics::plot(df$sd ~ df$sm, xlab = "m/z", ylab = "scaled MD")
-        return(df)
-}
-
-#' plot the kendrick mass defect diagram
-#' @param data vector with the name m/z
-#' @param cutoff remove the low intensity
-#' @return NULL
-#' @examples
-#' \dontrun{
-#' mz <- c(10000,5000,20000,100,40000)
-#' names(mz) <- c(100.1022,245.2122,267.3144,400.1222,707.2294)
-#' plotkms(mz)
-#' }
-#' @export
-plotkms <- function(data, cutoff = 1000) {
-        data <- data[data > cutoff]
-        mz <- as.numeric(names(data))
-        km <- mz * 14/14.01565
-        kmd <- round(km) - km
-        graphics::smoothScatter(kmd ~ round(km), xlab = "Kendrick nominal mass",
-                                ylab = "Kendrick mass defect")
-}
-#' to do
-#' Van Krevelen diagram
